from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

references = SchLib(tool=SKIDL).add_parts(*[
        Part(name='CJ432',dest=TEMPLATE,tool=SKIDL,keywords='diode device shunt regulator',description='Shunt Regulator, SOT-23',ref_prefix='D',num_units=1,fplist=['SOT*23*'],do_erc=True,pins=[
            Pin(num='1',name='REF',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='ISL21070DIH306Z-TK',dest=TEMPLATE,tool=SKIDL,keywords='Micropower Voltage Reference 0.6V',description='ISL201070 Series, 0.6V 25μA Micropower Voltage Reference, SOT-23',ref_prefix='U',num_units=1,fplist=['SOT-23*'],do_erc=True,aliases=['ISL21070CIH320Z-TK', 'ISL21070CIH325Z-TK'],pins=[
            Pin(num='1',name='Vin',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='Vout',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True)]),
        Part(name='LM134H/NOPB',dest=TEMPLATE,tool=SKIDL,keywords='Adjustable Current Source 10mA',description='LM134H, 1μA to 10mA 3-Terminal Adjustable Current Source, TO-46',ref_prefix='U',num_units=1,fplist=['TO?46*'],do_erc=True,pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='LM285D-1.2',dest=TEMPLATE,tool=SKIDL,keywords='diode device voltage reference',description='2.500V Micropower Voltage Reference Diodes, SO-8',ref_prefix='D',num_units=1,fplist=['SOIC*3.9x4.9m*_Pitch1.27mm*'],do_erc=True,aliases=['LM285D-2.5', 'LM385D-1.2', 'LM385D-2.5'],pins=[
            Pin(num='1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='3',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='4',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='6',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='7',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='8',name='K',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='LM285M-ADJ',dest=TEMPLATE,tool=SKIDL,keywords='diode device voltage reference',description='Adjustable Micropower Voltage Reference Diodes, SO-8',ref_prefix='D',num_units=1,fplist=['SOIC*3.9x4.9m*_Pitch1.27mm*'],do_erc=True,aliases=['LM385M-ADJ'],pins=[
            Pin(num='1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='3',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='4',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='FB',do_erc=True),
            Pin(num='6',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='7',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='8',name='K',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='LM285S-1.2',dest=TEMPLATE,tool=SKIDL,keywords='diode device voltage reference',description='2.500V Micropower Voltage Reference Diodes, SO-8',ref_prefix='D',num_units=1,fplist=['SOIC*3.9x4.9m*_Pitch1.27mm*'],do_erc=True,aliases=['LM385S-1.2', 'LM285S-2.5', 'LM385S-2.5'],pins=[
            Pin(num='1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='3',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='4',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='6',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='8',name='K',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='LM285Z-2.5',dest=TEMPLATE,tool=SKIDL,keywords='diode device voltage reference',description='1.235V Micropower Voltage Reference Diodes, TO-92',ref_prefix='D',num_units=1,fplist=['TO?92*'],do_erc=True,aliases=['LM285Z-1.2', 'LM385Z-1.2', 'LM358Z-2.5', 'LM385BZ-2.5', 'LM385BZ-1.2'],pins=[
            Pin(num='1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='LM285Z-ADJ',dest=TEMPLATE,tool=SKIDL,keywords='diode device voltage reference',description='Adjustable Micropower Voltage Reference Diodes, TO-92',ref_prefix='D',num_units=1,fplist=['TO?92*'],do_erc=True,aliases=['LM385Z-ADJ'],pins=[
            Pin(num='1',name='FB',do_erc=True),
            Pin(num='2',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='LM334M/NOPB',dest=TEMPLATE,tool=SKIDL,keywords='Adjustable Current Source 10mA',description='LM334M, 1μA to 10mA 3-Terminal Adjustable Current Source, SO-8',ref_prefix='U',num_units=1,fplist=['SOIC*3.9x4.9m*_Pitch1.27mm*'],do_erc=True,pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='6',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='LM334SM/NOPB',dest=TEMPLATE,tool=SKIDL,keywords='Adjustable Current Source 10mA',description='LM334SM, 1μA to 10mA 3-Terminal Adjustable Current Source, SO-8 Alternate',ref_prefix='U',num_units=1,fplist=['SOIC*3.9x4.9m*_Pitch1.27mm*'],do_erc=True,pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='LM334Z/NOPB',dest=TEMPLATE,tool=SKIDL,keywords='Adjustable Current Source 10mA',description='LM334Z, 1μA to 10mA 3-Terminal Adjustable Current Source, TO-92',ref_prefix='U',num_units=1,fplist=['TO?92*'],do_erc=True,aliases=['LM334Z/LFT1', 'LM234Z-3/NOPB', 'LM234Z-6/NOPB'],pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='LM4030-4.096',dest=TEMPLATE,tool=SKIDL,keywords='diode device voltage reference shunt',description='4.096V Ultra-High Precision Shunt Voltage Reference, SOT-23-5',ref_prefix='D',num_units=1,fplist=['SOT?23*'],do_erc=True,aliases=['LM4030-2.5'],pins=[
            Pin(num='1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='NC_GND',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='3',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='4',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='LM4040DBZ-2.0',dest=TEMPLATE,tool=SKIDL,keywords='diode device voltage reference shunt',description='8.192V Precision Micropower Shunt Voltage Reference, SOT-23',ref_prefix='D',num_units=1,fplist=['SOT?*23'],do_erc=True,aliases=['LM4040DBZ-2.5', 'LM4040DBZ-3', 'LM4040DBZ-4.1', 'LM4040DBZ-5', 'LM4040DBZ-8.2', 'LM4040DBZ-10'],pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='NC',func=Pin.NOCONNECT,do_erc=True)]),
        Part(name='LM4040DCK-2.0',dest=TEMPLATE,tool=SKIDL,keywords='diode device voltage reference shunt',description='8.192V Precision Micropower Shunt Voltage Reference, SC-70',ref_prefix='D',num_units=1,fplist=['SC?70*'],do_erc=True,aliases=['LM4040DCK-2.5', 'LM4040DCK-3', 'LM4040DCK-4.1', 'LM4040DCK-5', 'LM4040DCK-8.2', 'LM4040DCK-10'],pins=[
            Pin(num='1',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='3',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='5',name='NC',func=Pin.NOCONNECT,do_erc=True)]),
        Part(name='LM4040LP-2.0',dest=TEMPLATE,tool=SKIDL,keywords='diode device voltage reference shunt',description='8.192V Precision Micropower Shunt Voltage Reference, TO-92',ref_prefix='D',num_units=1,fplist=['TO?92*'],do_erc=True,aliases=['LM4040LP-2.5', 'LM4040LP-3', 'LM4040LP-4.1', 'LM4040LP-5', 'LM4040LP-8.2', 'LM4040LP-10'],pins=[
            Pin(num='1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='LM4125AIM5-2.5/NOPB',dest=TEMPLATE,tool=SKIDL,keywords='Precision Micropower Low Dropout Voltage Reference 2.5V',description='LM4125-2.5, 2.5V ±0.5% Precision Micropower Low Dropout Voltage Reference, SOT-23-5',ref_prefix='U',num_units=1,fplist=['SOT-23*'],do_erc=True,aliases=['LM4125IM5-2.0/NOPB', 'LM4125IM5-2.5/NOPB'],pins=[
            Pin(num='1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='4',name='Vin',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='Vout',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='LT6657AHMS8-2.5',dest=TEMPLATE,tool=SKIDL,keywords='voltage reference vref',description='Precision voltage reference, 40V input, 10mA output, 3.0ppm/C drift, 5.0V output',ref_prefix='U',num_units=1,fplist=['MSOP*3x3mm*Pitch0.65mm*'],do_erc=True,aliases=['LT6657BHMS8-2.5', 'LT6657AHMS8-3', 'LT6657BHMS8-3', 'LT6657AHMS8-5', 'LT6657BHMS8-5'],pins=[
            Pin(num='1',name='DNC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='Vin',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='~SHDN',do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='DNC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='6',name='OUT',func=Pin.PWROUT,do_erc=True),
            Pin(num='7',name='DNC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='8',name='DNC',func=Pin.NOCONNECT,do_erc=True)]),
        Part(name='MAX6100',dest=TEMPLATE,tool=SKIDL,keywords='voltage reference ldo',description='Low-dropout high current voltage reference, 4.500V, ±0.4% accuracy, SOT-23 package',ref_prefix='U',num_units=1,fplist=['SOT-23*'],do_erc=True,aliases=['MAX6101', 'MAX6102', 'MAX6103', 'MAX6104', 'MAX6105', 'MAX6106', 'MAX6107'],pins=[
            Pin(num='1',name='IN',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='OUT',func=Pin.PWROUT,do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True)]),
        Part(name='MCP1525T-I/TO',dest=TEMPLATE,tool=SKIDL,keywords='Voltage Reference 4.096V',description='MCP1541, 4.096V Voltage Reference, TO-92',ref_prefix='U',num_units=1,fplist=['TO-92*'],do_erc=True,aliases=['MCP1541T-I/TO'],pins=[
            Pin(num='1',name='Vin',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='Vout',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='MCP1525T-I/TT',dest=TEMPLATE,tool=SKIDL,keywords='Voltage Reference 4.096V',description='MCP1541, 4.096V Voltage Reference, SOT-23',ref_prefix='U',num_units=1,fplist=['SOT-23*'],do_erc=True,aliases=['MCP1541-I/TT'],pins=[
            Pin(num='1',name='Vin',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='Vout',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='REF02AP',dest=TEMPLATE,tool=SKIDL,keywords='Precision Voltage Reference 5V',description='5V ±10mV Precision Voltage Reference, PDIP-8',ref_prefix='U',num_units=1,fplist=['DIP*W7.62mm*'],do_erc=True,aliases=['REF02BP'],pins=[
            Pin(num='1',name='NC',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='Vin',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='TEMP',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='TRIM',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='Vout',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='NC',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='NC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='REF02AU',dest=TEMPLATE,tool=SKIDL,keywords='Precision Voltage Reference 5V',description='5V ±10mV Precision Voltage Reference, SO8',ref_prefix='U',num_units=1,fplist=['SOIC*3.9x4.9m*_Pitch1.27mm*'],do_erc=True,aliases=['REF02BU'],pins=[
            Pin(num='1',name='NC',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='Vin',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='TEMP',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='TRIM',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='Vout',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='NC',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='NC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='REF102AP',dest=TEMPLATE,tool=SKIDL,keywords='Precision Voltage Reference 10V',description='10V ±2.5mV Precision Voltage Reference, PDIP-8',ref_prefix='U',num_units=1,fplist=['DIP*W7.62mm*'],do_erc=True,aliases=['REF102BP', 'REF102CP'],pins=[
            Pin(num='1',name='NC',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='Vin',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='TEMP',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='TRIM',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='Vout',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='NC',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='NR',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='REF102AU',dest=TEMPLATE,tool=SKIDL,keywords='Precision Voltage Reference 10V',description='10V ±2.5mV Precision Voltage Reference, SO8',ref_prefix='U',num_units=1,fplist=['SOIC*3.9x4.9m*_Pitch1.27mm*'],do_erc=True,aliases=['REF102BU', 'REF102CU'],pins=[
            Pin(num='1',name='NC',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='Vin',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='TEMP',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='TRIM',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='Vout',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='NC',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='NR',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='REF191',dest=TEMPLATE,tool=SKIDL,description='Precision voltage references 4.096V',ref_prefix='U',num_units=1,fplist=['DIP*W7.62mm*', 'SOIC*3.9x4.9m*_Pitch1.27mm*', 'TSSOP*4.4x3mm*Pitch0.65mm*'],do_erc=True,aliases=['REF192', 'REF193', 'REF194', 'REF195', 'REF196', 'REF198'],pins=[
            Pin(num='1',name='TP',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='Vin',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='~Sleep~',do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='TP',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='6',name='Vout',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='8',name='NC',func=Pin.NOCONNECT,do_erc=True)]),
        Part(name='REF3012',dest=TEMPLATE,tool=SKIDL,keywords='voltage reference',description='4.096V 50-ppm/°C Max, 50-μA, CMOS Voltage Reference in SOT-23-3',ref_prefix='U',num_units=1,fplist=['SOT-23*'],do_erc=True,aliases=['REF3020', 'REF3025', 'REF3030', 'REF3033', 'REF3040'],pins=[
            Pin(num='1',name='IN',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='OUT',func=Pin.PWROUT,do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True)]),
        Part(name='REF3212AMDBVREP',dest=TEMPLATE,tool=SKIDL,keywords='Micropower Prevision Voltage Reference 4.096V',description='REF3240A, 4.096V 100μA Micropower Precision Voltage Reference, SOT-23-6',ref_prefix='U',num_units=1,fplist=['SOT-23*'],do_erc=True,aliases=['REF3220AMDBVREP', 'REF3225AMDBVREP', 'REF3230AMDBVREP', 'REF3233AMDBVREP', 'REF3240AMDBVREP'],pins=[
            Pin(num='1',name='GND_F',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='GND_S',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='ENABLE',do_erc=True),
            Pin(num='4',name='IN',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='OUT_S',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='OUT_F',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='REF5020AD',dest=TEMPLATE,tool=SKIDL,keywords='Low Noise Precision Voltage Reference 5V',description='5V 0.05% 10mA Low Noise Precision Voltage Reference, SO8',ref_prefix='U',num_units=1,fplist=['SOIC*3.9x4.9m*_Pitch1.27mm*'],do_erc=True,aliases=['REF5025AD', 'REF5030AD', 'REF5040AD', 'REF5045AD', 'REF5050AD', 'REF5010AD', 'REF5020ID', 'REF5025ID', 'REF5030ID', 'REF5040ID', 'REF5045ID', 'REF5050ID', 'REF5010ID'],pins=[
            Pin(num='1',name='DNC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='Vin',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='Temp',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='Trim/NR',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='Vout',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='8',name='DNC',func=Pin.NOCONNECT,do_erc=True)]),
        Part(name='REF5020ADGK',dest=TEMPLATE,tool=SKIDL,keywords='Low Noise Precision Voltage Reference 5V',description='5V 0.05% 10mA Low Noise Precision Voltage Reference, MSOP-8',ref_prefix='U',num_units=1,fplist=['MSOP*3x3mm*Pitch0.65mm*'],do_erc=True,aliases=['REF5025ADGK', 'REF5030ADGK', 'REF5040ADGK', 'REF5045ADGK', 'REF5050ADGK', 'REF5010ADGK', 'REF5020IDGK', 'REF5025IDGK', 'REF5030IDGK', 'REF5040IDGK', 'REF5045IDGK', 'REF5050IDGK', 'REF5010IDGK'],pins=[
            Pin(num='1',name='DNC',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='Vin',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='Temp',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='Trim/NR',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='Vout',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='NC',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='DNC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='TL431D',dest=TEMPLATE,tool=SKIDL,keywords='diode device shunt regulator',description='Shunt Regulator, SO8',ref_prefix='D',num_units=1,fplist=['SOIC*3.9x4.9m*_Pitch1.27mm*'],do_erc=True,pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',do_erc=True),
            Pin(num='3',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='5',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='6',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='8',name='REF',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TL431DBV',dest=TEMPLATE,tool=SKIDL,keywords='diode device shunt regulator',description='Shunt Regulator, SOT-23-5',ref_prefix='D',num_units=1,fplist=['SOT-23*'],do_erc=True,pins=[
            Pin(num='1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='NC_SUBSTRATE',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='3',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='REF',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TL431DBZ',dest=TEMPLATE,tool=SKIDL,keywords='diode device shunt regulator',description='Shunt Regulator, SOT-23',ref_prefix='D',num_units=1,fplist=['SOT*23*'],do_erc=True,pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='REF',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TL431DCK',dest=TEMPLATE,tool=SKIDL,keywords='diode device shunt regulator',description='Shunt Regulator, SC-70',ref_prefix='D',num_units=1,fplist=['SC-70*'],do_erc=True,pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='REF',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TL431KTP',dest=TEMPLATE,tool=SKIDL,keywords='diode device shunt regulator',description='Shunt Regulator, TO-252',ref_prefix='D',num_units=1,fplist=['TO*252'],do_erc=True,pins=[
            Pin(num='1',name='REF',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='K',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TL431LP',dest=TEMPLATE,tool=SKIDL,keywords='diode device regulator shunt',description='Shunt Regulator, TO-92',ref_prefix='D',num_units=1,fplist=['TO*'],do_erc=True,pins=[
            Pin(num='1',name='REF',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='K',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TL431P',dest=TEMPLATE,tool=SKIDL,keywords='diode device shunt regulator',description='Shunt Regulator, PDIP-8',ref_prefix='D',num_units=1,fplist=['DIP*W7.62mm*'],do_erc=True,pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='8',name='REF',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TL431PK',dest=TEMPLATE,tool=SKIDL,keywords='diode device shunt regulator',description='Shunt Regulator, SOT-89',ref_prefix='D',num_units=1,fplist=['SOT*89*'],do_erc=True,pins=[
            Pin(num='1',name='REF',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='K',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TL431PS',dest=TEMPLATE,tool=SKIDL,keywords='diode device shunt regulator',description='Shunt Regulator, MSOP-8',ref_prefix='D',num_units=1,fplist=['MSOP*'],do_erc=True,pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='8',name='REF',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TL431PW',dest=TEMPLATE,tool=SKIDL,keywords='diode device shunt regulator',description='Shunt Regulator, TSSOP-8',ref_prefix='D',num_units=1,fplist=['TSSOP*'],do_erc=True,pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='8',name='REF',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TL432DBV',dest=TEMPLATE,tool=SKIDL,keywords='diode device shunt regulator',description='Shunt Regulator, SOT-23-5',ref_prefix='D',num_units=1,fplist=['SOT?23*'],do_erc=True,pins=[
            Pin(num='1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='4',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='REF',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TL432DBZ',dest=TEMPLATE,tool=SKIDL,keywords='diode device shunt regulator',description='Shunt Regulator, SOT-23',ref_prefix='D',num_units=1,fplist=['SOT*23*'],do_erc=True,pins=[
            Pin(num='1',name='REF',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='TL432PK',dest=TEMPLATE,tool=SKIDL,keywords='diode device shunt regulator',description='Shunt Regulator, SOT-89',ref_prefix='D',num_units=1,fplist=['SOT*89*'],do_erc=True,pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='REF',func=Pin.PASSIVE,do_erc=True)])])


from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

siliconi = SchLib(tool=SKIDL).add_parts(*[
        Part(name='D469',dest=TEMPLATE,tool=SKIDL,keywords='High-Current Driver',description='Quad High-Current Power Driver',ref_prefix='U',num_units=4,do_erc=True,pins=[
            Pin(num='7',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='V+',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='IN1',do_erc=True),
            Pin(num='2',name='IN',do_erc=True),
            Pin(num='13',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='IN1',do_erc=True),
            Pin(num='4',name='IN',do_erc=True),
            Pin(num='12',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='IN1',do_erc=True),
            Pin(num='6',name='IN',do_erc=True),
            Pin(num='11',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='IN1',do_erc=True),
            Pin(num='9',name='IN',do_erc=True),
            Pin(num='10',name='OUT',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='DG411',dest=TEMPLATE,tool=SKIDL,keywords='CMOS Analog Switche',description='Monolithic Quad SPST, CMOS Analog Switches',ref_prefix='U',num_units=4,do_erc=True,pins=[
            Pin(num='4',name='V-',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='V+',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='SW',do_erc=True),
            Pin(num='2',name='IN',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='OUT',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='OUT',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='IN',func=Pin.PASSIVE,do_erc=True),
            Pin(num='8',name='SW',do_erc=True),
            Pin(num='9',name='SW',do_erc=True),
            Pin(num='10',name='IN',func=Pin.PASSIVE,do_erc=True),
            Pin(num='11',name='OUT',func=Pin.PASSIVE,do_erc=True),
            Pin(num='14',name='OUT',func=Pin.PASSIVE,do_erc=True),
            Pin(num='15',name='IN',func=Pin.PASSIVE,do_erc=True),
            Pin(num='16',name='SW',do_erc=True)])])


from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

bbd = SchLib(tool=SKIDL).add_parts(*[
        Part(name='MN3005',dest=TEMPLATE,tool=SKIDL,keywords='Matsushita Panasonic BBD',description='4096-STAGE LONG DELAY BBD (bucket brigade device), delay time 20.48ms to 204.8ms, S/N 75dB, clock frequency range 10KHz to 100KHz',ref_prefix='U',num_units=1,fplist=['DIP-8*'],do_erc=True,pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='CP2',do_erc=True),
            Pin(num='3',name='OUT1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='OUT2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='CP1',do_erc=True),
            Pin(num='7',name='IN',do_erc=True),
            Pin(num='8',name='VGG',func=Pin.PWRIN,do_erc=True)]),
        Part(name='MN3007',dest=TEMPLATE,tool=SKIDL,keywords='Matsushita Panasonic BBD',description='1024-STAGE LOW NOISE BBD (bucket brigade device), delay time 5.12ms to 51.2ms, S/N 80dB, clock frequency range 10KHz to 100KHz',ref_prefix='U',num_units=1,fplist=['DIP-8*'],do_erc=True,pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='CP1',do_erc=True),
            Pin(num='3',name='IN',do_erc=True),
            Pin(num='4',name='VGG',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='CP2',do_erc=True),
            Pin(num='7',name='OUT1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='OUT2',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='MN3101',dest=TEMPLATE,tool=SKIDL,keywords='Matsushita Panasonic BBD CMOS',description='CMOS CLOCK GENERATOR/DRIVER FOR LOW VOLTAGE OPERATION BBD (bucket brigade device), for the MN3200 series BBD, self oscillation and separate exitation, two phase clock output, single supply source 4V to 10V',ref_prefix='U',num_units=1,fplist=['DIP-8*'],do_erc=True,aliases=['MN3102'],pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='CP1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='CP2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='OX3',do_erc=True),
            Pin(num='6',name='OX2',do_erc=True),
            Pin(num='7',name='OX1',do_erc=True),
            Pin(num='8',name='VGG_OUT',func=Pin.PWROUT,do_erc=True)]),
        Part(name='MN3207',dest=TEMPLATE,tool=SKIDL,keywords='Matsushita Panasonic BBD',description='1024-STAGE LOW VOLTAGE OPERATION LOW NOISE BBD (bucket brigade device), delay time 2.56ms to 51.2ms, S/N 73dB, clock frequency range 10KHz to 200KHz',ref_prefix='U',num_units=1,fplist=['DIP-8*'],do_erc=True,pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='CP1',do_erc=True),
            Pin(num='3',name='IN',do_erc=True),
            Pin(num='4',name='VGG',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='CP2',do_erc=True),
            Pin(num='7',name='OUT1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='OUT2',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='RD5106A',dest=TEMPLATE,tool=SKIDL,keywords='EG&G RETICON BBD N-channel silicon-gate',description='Analog Delay Line 512 sample bucket brigade device, 1msec to more than 2seconds, input signal frequency range 0 to 170KHz, clock frequency range 500Hz to 1MHz',ref_prefix='U',num_units=1,fplist=['DIP-8*'],do_erc=True,aliases=['RD5107A'],pins=[
            Pin(num='1',name='Clock',do_erc=True),
            Pin(num='2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='4',name='Output',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VBB',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='Input',do_erc=True),
            Pin(num='7',name='Sync',do_erc=True),
            Pin(num='8',name='VDD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='SAD1024',dest=TEMPLATE,tool=SKIDL,keywords='EG&G RETICON BBD N-channel silicon-gate',description='SAD-512 ANALOG DELAY LINE, bucket brigade device, 512 stages, signal frequency range 0 to 200KHz, clock frequency range 1.5KHz to 1.5MHz',ref_prefix='U',num_units=2,fplist=['DIP-16*'],do_erc=True,aliases=['SAD512'],pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='7',name='Vdd',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='Vbb',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='16',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='IN_A',do_erc=True),
            Pin(num='3',name='02A',do_erc=True),
            Pin(num='5',name='OUT_A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name="OUT_A'",func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='01A',do_erc=True),
            Pin(num='10',name='01B',do_erc=True),
            Pin(num='11',name="OUT_B'",func=Pin.OUTPUT,do_erc=True),
            Pin(num='12',name='OUT_B',func=Pin.OUTPUT,do_erc=True),
            Pin(num='14',name='02B',do_erc=True),
            Pin(num='15',name='IN_B',do_erc=True)]),
        Part(name='TDA1022',dest=TEMPLATE,tool=SKIDL,keywords='PHILIPS BBD MOS monolithic delay analogue',description='BUCKET BRIGADE DELAY LINE FOR ANALOGUE SIGNALS, 512 stages, delay time 0.512ms to 51.2ms, signal frequency range 0 to 45KHz, clock frequency range 5KHz to 500KHz',ref_prefix='U',num_units=1,fplist=['DIP-16*'],do_erc=True,pins=[
            Pin(num='1',name='CL1',do_erc=True),
            Pin(num='2',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='3',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='4',name='CL2',do_erc=True),
            Pin(num='5',name='Input',do_erc=True),
            Pin(num='6',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='7',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='8',name='Output513',func=Pin.OUTPUT,do_erc=True),
            Pin(num='9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='11',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='12',name='Output512',func=Pin.OUTPUT,do_erc=True),
            Pin(num='13',name='V13-16',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='15',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='16',name='GND',func=Pin.PWRIN,do_erc=True)])])


from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

valves = SchLib(tool=SKIDL).add_parts(*[
        Part(name='CK6418',dest=TEMPLATE,tool=SKIDL,keywords='subminiature pentode valve',description='Subminiature Pentode',ref_prefix='U',num_units=2,fplist=['VALVE*MINI*PENTODE*LINEAR*'],do_erc=True,aliases=['CK548DX', 'JAN6418', 'NOS-6418'],pins=[
            Pin(num='3',name='F+,G3',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='P',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='G2',do_erc=True),
            Pin(num='4',name='G1',do_erc=True),
            Pin(num='5',name='F+,G3',func=Pin.PWRIN,do_erc=True)]),
        Part(name='EABC80',dest=TEMPLATE,tool=SKIDL,keywords='diode triode valve',description='triple diode triode',ref_prefix='U',num_units=4,fplist=['VALVE*NOVAL*P*'],do_erc=True,aliases=['6AK8', '9AK8', 'PABC80', 'UABC80'],pins=[
            Pin(num='2',name='A2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='K',do_erc=True),
            Pin(num='1',name='A1',do_erc=True),
            Pin(num='6',name='A3',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='K',do_erc=True),
            Pin(num='7',name='K',do_erc=True),
            Pin(num='8',name='G',do_erc=True),
            Pin(num='9',name='A2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='F1',do_erc=True),
            Pin(num='5',name='F2',do_erc=True)]),
        Part(name='EC92',dest=TEMPLATE,tool=SKIDL,keywords='triode valve',description='single triode',ref_prefix='U',num_units=2,fplist=['VALVE*MINI*P*'],do_erc=True,pins=[
            Pin(num='1',name='A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='G',do_erc=True),
            Pin(num='7',name='K',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='F1',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='F2',func=Pin.PWRIN,do_erc=True)]),
        Part(name='ECC81',dest=TEMPLATE,tool=SKIDL,keywords='triode valve',description='double triode',ref_prefix='U',num_units=3,fplist=['VALVE*NOVAL*P*'],do_erc=True,aliases=['ECC83'],pins=[
            Pin(num='6',name='A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='G',do_erc=True),
            Pin(num='8',name='K',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='G',do_erc=True),
            Pin(num='3',name='K',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='F1',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='F1',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='F2',func=Pin.PWRIN,do_erc=True)]),
        Part(name='ECC88',dest=TEMPLATE,tool=SKIDL,keywords='triode valve',description='double triode, low-noise',ref_prefix='U',num_units=3,fplist=['VALVE*NOVAL*P*'],do_erc=True,pins=[
            Pin(num='1',name='A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='G',do_erc=True),
            Pin(num='3',name='K',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='G',do_erc=True),
            Pin(num='8',name='K',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='F1',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='F2',func=Pin.PWRIN,do_erc=True)]),
        Part(name='ECH81',dest=TEMPLATE,tool=SKIDL,keywords='triode heptode valve',description='triode heptode',ref_prefix='U',num_units=3,fplist=['VALVE*NOVAL*P*'],do_erc=True,pins=[
            Pin(num='3',name='K',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='9',name='G',do_erc=True),
            Pin(num='1',name='G2_G4',do_erc=True),
            Pin(num='2',name='G1',do_erc=True),
            Pin(num='6',name='A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='G3',do_erc=True),
            Pin(num='~',name='K_G5',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='F1',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='F2',func=Pin.PWRIN,do_erc=True)]),
        Part(name='ECL82',dest=TEMPLATE,tool=SKIDL,keywords='triode pentode valve',description='triode pentode',ref_prefix='U',num_units=3,fplist=['VALVE*NOVAL*P*'],do_erc=True,pins=[
            Pin(num='1',name='G',do_erc=True),
            Pin(num='8',name='K',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='K_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='G1',do_erc=True),
            Pin(num='6',name='A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='G2',do_erc=True),
            Pin(num='4',name='F1',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='F2',func=Pin.PWRIN,do_erc=True)]),
        Part(name='ECL86',dest=TEMPLATE,tool=SKIDL,keywords='triode pentode valve',description='triode pentode',ref_prefix='U',num_units=3,fplist=['VALVE*NOVAL*P*'],do_erc=True,pins=[
            Pin(num='1',name='G',do_erc=True),
            Pin(num='2',name='K',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='G2',do_erc=True),
            Pin(num='6',name='A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='K_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='G1',do_erc=True),
            Pin(num='4',name='F1',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='F2',func=Pin.PWRIN,do_erc=True)]),
        Part(name='EF80',dest=TEMPLATE,tool=SKIDL,keywords='pentode valve',description='pentode',ref_prefix='U',num_units=2,fplist=['VALVE*NOVAL*P*'],do_erc=True,aliases=['EF85'],pins=[
            Pin(num='2',name='G1',do_erc=True),
            Pin(num='3',name='F1',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='S',do_erc=True),
            Pin(num='7',name='A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='G2',do_erc=True),
            Pin(num='9',name='G3',do_erc=True),
            Pin(num='4',name='F1',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='F2',func=Pin.PWRIN,do_erc=True)]),
        Part(name='EF83',dest=TEMPLATE,tool=SKIDL,keywords='pentode valve',description='pentode',ref_prefix='U',num_units=2,fplist=['VALVE*NOVAL*P*'],do_erc=True,aliases=['EF86'],pins=[
            Pin(num='1',name='G2',do_erc=True),
            Pin(num='3',name='K',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='S',do_erc=True),
            Pin(num='8',name='G3',do_erc=True),
            Pin(num='9',name='G1',do_erc=True),
            Pin(num='4',name='F1',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='F2',func=Pin.PWRIN,do_erc=True)]),
        Part(name='EL34',dest=TEMPLATE,tool=SKIDL,keywords='pentode valve',description='pentode, 25W',ref_prefix='U',num_units=2,fplist=['VALVE*OCTAL*'],do_erc=True,pins=[
            Pin(num='1',name='G3',do_erc=True),
            Pin(num='3',name='A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='G2',do_erc=True),
            Pin(num='5',name='G1',do_erc=True),
            Pin(num='8',name='F1',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='F1',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='F2',func=Pin.PWRIN,do_erc=True)]),
        Part(name='EL84',dest=TEMPLATE,tool=SKIDL,keywords='pentode valve',description='pentode, 12W',ref_prefix='U',num_units=2,fplist=['VALVE*NOVAL*P*'],do_erc=True,pins=[
            Pin(num='2',name='G1',do_erc=True),
            Pin(num='3',name='K_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='9',name='G2',do_erc=True),
            Pin(num='4',name='F1',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='F2',func=Pin.PWRIN,do_erc=True)]),
        Part(name='EM84',dest=TEMPLATE,tool=SKIDL,keywords='indicator tube valve magic eye',description='indicator tube "magic eye"',ref_prefix='U',num_units=3,fplist=['VALVE*NOVAL*P*'],do_erc=True,pins=[
            Pin(num='2',name='K',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='L',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='ST',do_erc=True),
            Pin(num='1',name='G',do_erc=True),
            Pin(num='9',name='A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='~',name='F1',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='F1',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='F2',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STABI',dest=TEMPLATE,tool=SKIDL,do_erc=True)])


# -*- coding: utf-8 -*-

# MIT license
#
# Copyright (C) 2018 by XESS Corp.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

"""
Handles aliases for parts and other stuff.
"""

from __future__ import unicode_literals
from __future__ import print_function
from __future__ import division
from __future__ import absolute_import
from builtins import str
from future import standard_library
standard_library.install_aliases()

import re

from .utilities import *


class Alias(object):
    """
    An alias can be added to another object to give it another name.
    Since an object might have several aliases, each alias can be tagged
    with an identifier to discriminate between them.

    Args:
        name: The alias name.
        id_tag: The identifier tag.
    """

    def __init__(self, name, id_tag=None):
        self.name = name
        self.id_ = id_tag

    def __eq__(self, other):
        """
        Return true if one alias is equal to another.

        The aliases are equal if the following conditions are both true::

            1. The ids must match or one or both ids must be something
                that evaluates to False (i.e., None, empty string or list, etc.).

            2. The names must match based on using one name as a
                regular expression to compare to the other.

        Args:
            other: The Alias object which self will be compared to.
        """
        return (not self.id_ or not other.id_ or other.id_ == self.id_) and \
            (fullmatch(str(other.name), str(self.name), flags=re.IGNORECASE) or
             fullmatch(str(self.name), str(other.name), flags=re.IGNORECASE))
